@@ -1,6 +1,7 @@
 
 import os
 import time
+import yaml
 
 from typeguard import typechecked
 from benchmark_runner.common.logger.logger_time_stamp import logger_time_stamp, logger
@@ -18,19 +19,20 @@ class BenchmarkOperatorWorkloads:
     """
     This class contains all the custom_workloads
     """
-    def __init__(self, kubeadmin_password: str = '', es_host: str = '', es_port: str = '', workload: str = ''):
+    def __init__(self, kubeadmin_password: str = '', es_host: str = '', es_port: str = ''):
         self.__ssh = SSH()
         self.__kubeadmin_password = kubeadmin_password
         self.__oc = OC(kubeadmin_password=self.__kubeadmin_password)
-        self.__dir_path = os.path.dirname(os.path.realpath(__file__))
-        self.__workload = workload
+        # if mount is exist - path inside Dockerfile
+        if os.path.exists('/benchmark_runner/benchmark_operator/templates/'):
+            self.__dir_path = '/benchmark_runner/benchmark_operator/templates/'
+        else:
+            self.__dir_path = os.path.dirname(os.path.realpath(__file__))
+        self.__current_run_path = f'{self.__dir_path}/templates/current_run'
         self.__es_host = es_host
         self.__es_port = es_port
-        self.__current_run_path = os.path.join(self.__dir_path, 'current_run')
         if es_host and es_port:
             self.__es_operations = ESOperations(es_host=self.__es_host, es_port=self.__es_port)
-        else:
-            self.__verify_elasticsearch_exist_for_vm_workload(workload=self.__workload)
         # Generate templates class
         self.__template = TemplateOperations()
         self.__oc.login()
@@ -43,12 +45,12 @@ class BenchmarkOperatorWorkloads:
         This method verify that elastic search exist for vm workloads to verify completed status
         :return: error in case no elasticsearch
         """
-        #if 'vm' in workload and not self.__es_host:
-        #    raise VMWorkloadNeedElasticSearch
+        if 'vm' in workload and not self.__es_host:
+           raise VMWorkloadNeedElasticSearch
 
-    def __get_run_yamls(self, extension='.yaml'):
+    def __remove_current_run_yamls(self, extension='.yaml'):
         """
-        This method get all run yamls files
+        This method remove all current run yamls files
         :return:
         """
         name_list = []
@@ -72,7 +74,53 @@ class BenchmarkOperatorWorkloads:
             logger.info('yaml file {} does not exist')
 
     @logger_time_stamp
-    def check_if_exist_run_yaml(self, extension: str = '.yaml'):
+    def update_node_selector(self, base_path: str = '', yaml_path: str = '', pin_node: str = ''):
+        """
+        This method update node selector in yaml
+        @return:
+        """
+        data = []
+        # Read YAML file and inject node selector in the right place
+        with open(os.path.join(base_path, yaml_path), 'r') as stream:
+            try:
+                documents = yaml.safe_load_all(stream)
+                for doc in documents:
+                    if doc.get('spec'):
+                        doc['spec']['template']['spec']['nodeSelector'] = {
+                            'kubernetes.io/hostname': f"{self.__environment_variables_dict.get(pin_node, '')}"}
+                    data.append(doc)
+            except yaml.YAMLError as exc:
+                print(exc)
+
+        # Write YAML file
+        with open(os.path.join(self.__environment_variables_dict.get('runner_path', ''),
+                               'benchmark-operator/config/manager/manager.yaml'), 'w', encoding='utf8') as outfile:
+            yaml.safe_dump_all(data, outfile, default_flow_style=False, allow_unicode=True)
+
+    @logger_time_stamp
+    def change_resource_limit_cpu_benchmark_operator_temp_patch(self, base_path: str = '', yaml_path: str = ''):
+        """
+        # This method is for update resources limit to 0 in manager.yaml
+        @return:
+        """
+        data = []
+        # Read YAML file and inject node selector in the right place
+        with open(os.path.join(base_path, yaml_path), 'r') as stream:
+            try:
+                documents = yaml.safe_load_all(stream)
+                for doc in documents:
+                    if doc.get('spec'):
+                        doc['spec']['template']['spec']['containers'][1]['resources']['limits']['cpu'] = "0.0"
+                    data.append(doc)
+            except yaml.YAMLError as exc:
+                print(exc)
+
+        # Write YAML file
+        with open(os.path.join(base_path, yaml_path), 'w', encoding='utf8') as outfile:
+            yaml.safe_dump_all(data, outfile, default_flow_style=False, allow_unicode=True)
+
+    @logger_time_stamp
+    def remove_if_exist_run_yaml(self, extension: str = '.yaml'):
         """
         This method remove all run yaml files in yaml folder
         :return:
@@ -97,6 +145,8 @@ class BenchmarkOperatorWorkloads:
         os.chdir(os.path.join(runner_path, benchmark_operator_path))
         self.__ssh.run('make deploy')
         self.__oc.wait_for_pod_create(pod_name='benchmark-controller-manager')
+        self.__oc.wait_for_initialized(label='control-plane=controller-manager', label_uuid=False)
+        self.__oc.wait_for_ready(label='control-plane=controller-manager', label_uuid=False)
         os.chdir(current_dir)
 
     @logger_time_stamp
@@ -175,7 +225,7 @@ class BenchmarkOperatorWorkloads:
         @return:
         """
         self.__oc.delete_pod_sync(yaml=yaml, pod_name=pod_name)
-        self.check_if_exist_run_yaml()
+        self.remove_if_exist_run_yaml()
         self.make_undeploy_benchmark_controller_manager(runner_path=environment_variables.environment_variables_dict['runner_path'])
 
     @logger_time_stamp
@@ -184,7 +234,7 @@ class BenchmarkOperatorWorkloads:
         This method tear down vm in case of error
         """
         self.__oc.delete_vm_sync(yaml=yaml, vm_name=vm_name)
-        self.check_if_exist_run_yaml()
+        self.remove_if_exist_run_yaml()
         self.make_undeploy_benchmark_controller_manager(runner_path=environment_variables.environment_variables_dict['runner_path'])
 
 #***********************************************************************************************
@@ -205,7 +255,7 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_completed(label='app=stressng_workload', workload=workload)
             if self.__es_host:
                 # verify that data upload to elastic search according to unique uuid
-                self.__es_operations.verify_es_data_uploaded(index='ripsaw-stressng-results', uuid=self.__oc.get_long_uuid(workload=workload))
+                self.__es_operations.verify_es_data_uploaded(index=f'{workload}-results', uuid=self.__oc.get_long_uuid(workload=workload))
             self.__oc.delete_pod_sync(
                 yaml=os.path.join(f'{self.__current_run_path}', f'{self.stressng_pod.__name__}.yaml'),
                 pod_name=f'{workload}-workload')
@@ -227,8 +277,8 @@ class BenchmarkOperatorWorkloads:
         try:
             workload = self.stressng_vm.__name__.replace('_', '-')
             self.__oc.create_vm_sync(yaml=os.path.join(f'{self.__current_run_path}', f'{self.stressng_vm.__name__}.yaml'), vm_name=f'{workload}-workload')
-            self.__oc.wait_for_initialized(label='kubevirt.io=virt-launcher', workload=workload, label_uuid=False)
-            self.__oc.wait_for_ready(label='kubevirt.io=virt-launcher', workload=workload, label_uuid=False)
+            self.__oc.wait_for_initialized(label='app=stressng_workload', workload=workload)
+            self.__oc.wait_for_ready(label='app=stressng_workload', workload=workload)
             # verify that data upload to elastic search, vm completed status
             if self.__es_host:
                 self.__es_operations.verify_es_data_uploaded(index=f'{workload}-results', uuid=self.__oc.get_long_uuid(workload=workload))
@@ -297,7 +347,7 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_ready(label='app=uperf-bench-client', workload=workload)
             # verify that data upload to elastic search, vm completed status
             if self.__es_host:
-                self.__es_operations.verify_es_data_uploaded(index=f'{workload}-results', uuid=self.__oc.get_long_uuid(workload='uperf'), workload=self.uperf_vm.__name__)
+                self.__es_operations.verify_es_data_uploaded(index=f'{workload}-results', uuid=self.__oc.get_long_uuid(workload=workload), workload=self.uperf_vm.__name__)
             self.__oc.delete_vm_sync(yaml=os.path.join(f'{self.__current_run_path}', f'{self.uperf_vm.__name__}.yaml'),
                                      vm_name='uperf-server')
         except ElasticSearchDataNotUploaded as err:
@@ -402,7 +452,7 @@ class BenchmarkOperatorWorkloads:
         :return:
         """
         # remove running workloads if exist
-        self.check_if_exist_run_yaml()
+        self.remove_if_exist_run_yaml()
         workload_name = workload_full_name.split('_')
         if 'hammerdb' in workload_full_name:
             self.__template.generate_hammerdb_yamls(workload=f'{workload_name[0]}_{workload_name[1]}', database=workload_name[2])
@@ -416,7 +466,7 @@ class BenchmarkOperatorWorkloads:
         self.__remove_run_workload_yaml_file(workload_full_name=workload_full_name)
 
     @logger_time_stamp
-    def run_workload(self):
+    def run_workload(self, workload: str):
         """
         This method run the input workload
         :return:
@@ -424,14 +474,14 @@ class BenchmarkOperatorWorkloads:
 
         self.make_undeploy_benchmark_controller_manager_if_exist(runner_path=environment_variables.environment_variables_dict['runner_path'])
 
-        # elasticsearch is must for VM workload for completed status verifications
-        #self.__verify_elasticsearch_exist_for_vm_workload(workload=self.__workload)
+        #  elasticsearch is must for VM workload for completed status verifications
+        self.__verify_elasticsearch_exist_for_vm_workload(workload)
 
         # make deploy benchmark controller manager
         self.make_deploy_benchmark_controller_manager(runner_path=environment_variables.environment_variables_dict['runner_path'])
 
         # run workload
-        self.run_workload_func(workload_full_name=self.__workload)
+        self.run_workload_func(workload_full_name=workload)
 
         # make undeploy benchmark controller manager
         self.make_undeploy_benchmark_controller_manager(runner_path=environment_variables.environment_variables_dict['runner_path'])
