@@ -7,28 +7,48 @@ class EnvironmentVariables:
     This class manage environment variable parameters
     """
     def __init__(self):
-        self._environment_variables_dict = {}
-        # hard coded parameters
-        self._environment_variables_dict['workloads'] = ['hammerdb_pod_mariadb', 'hammerdb_pod_mssql', 'hammerdb_pod_postgres',
-                          'hammerdb_vm_mariadb', 'hammerdb_vm_mssql', 'hammerdb_vm_postgres',
-                          'stressng_pod', 'stressng_vm',
-                          'uperf_pod', 'uperf_vm']
-        self._environment_variables_dict['namespace'] = os.environ.get('namespace', 'benchmark-operator')
 
-        # dynamic parameters
-        self._environment_variables_dict['kubeadmin_password'] = os.environ.get('KUBEADMIN_PASSWORD', '')
+        self._environment_variables_dict = {}
+
+        # hard coded parameters
+        self._environment_variables_dict['workloads'] = ['stressng_pod', 'stressng_vm', 'uperf_pod', 'uperf_vm', 'hammerdb_pod_mariadb', 'hammerdb_vm_mariadb',  'hammerdb_pod_postgres', 'hammerdb_vm_postgres', 'hammerdb_pod_mssql', 'hammerdb_vm_mssql']
+        self._environment_variables_dict['namespace'] = os.environ.get('namespace', 'benchmark-operator')
+        # run Hammerdb workload with ocs pvc
+        self._environment_variables_dict['ocs_pvc'] = os.environ.get('ocs_pvc', 'true')
+        #  TODO: CPU issue in functional environment, need to walk around only in Azure functional environment
+        self._environment_variables_dict['functional_resource_limit'] = os.environ.get('functional_resource_limit', 'true')
+
+        ##################################################################################################
+        # dynamic parameters - configure for local run
         self._environment_variables_dict['workload'] = os.environ.get('WORKLOAD', '')
-        self._environment_variables_dict['elasticsearch'] = os.environ.get('ELASTICSEARCH', '')
-        self._environment_variables_dict['elasticsearch_port'] = os.environ.get('ELASTICSEARCH_PORT', '')
+        self._environment_variables_dict['kubeadmin_password'] = os.environ.get('KUBEADMIN_PASSWORD', '')
+
+        # PIN=node selector
+        self._environment_variables_dict['pin_node_benchmark_operator'] = os.environ.get('PIN_NODE_BENCHMARK_OPERATOR', '')
         self._environment_variables_dict['pin_node1'] = os.environ.get('PIN_NODE1', '')
         self._environment_variables_dict['pin_node2'] = os.environ.get('PIN_NODE2', '')
+
+        # ElasticSearch
+        self._environment_variables_dict['elasticsearch'] = os.environ.get('ELASTICSEARCH', '')
+        self._environment_variables_dict['elasticsearch_port'] = os.environ.get('ELASTICSEARCH_PORT', '')
+
         # This path is for benchmark-operator path
         self._environment_variables_dict['runner_path'] = os.environ.get('RUNNER_PATH', '')
+        # end dynamic parameters - configure for local run
+        ##################################################################################################
+
+        # Node Selector functionality
+        if self._environment_variables_dict['pin_node1']:
+            self._environment_variables_dict['pin'] = 'true'
+        else:
+            self._environment_variables_dict['pin'] = 'false'
+        # if pin_node2 not exist, get pin_node1 value
+        if self._environment_variables_dict['pin_node1'] and not self._environment_variables_dict['pin_node2']:
+            self._environment_variables_dict['pin_node2'] = self._environment_variables_dict['pin_node1']
+
+        # ElasticSearch functionality
         if self._environment_variables_dict['elasticsearch'] and self._environment_variables_dict['elasticsearch_port']:
-            self._environment_variables_dict['elasticsearch_url'] = f"http://{self._environment_variables_dict['elasticsearch']}:{self._environment_variables_dict['elasticsearch_port']}"
-        # in case no port
-        elif self._environment_variables_dict['elasticsearch'] and not self._environment_variables_dict['elasticsearch_port']:
-            self._environment_variables_dict['elasticsearch'] = self._environment_variables_dict['elasticsearch']
+            self._environment_variables_dict['elasticsearch_url'] = f"{self._environment_variables_dict['elasticsearch']}:{self._environment_variables_dict['elasticsearch_port']}"
         else:
             self._environment_variables_dict['elasticsearch_url'] = ''
 
