@@ -28,8 +28,17 @@ def main():
     es_host = environment_variables_dict.get('elasticsearch', '')
     es_port = environment_variables_dict.get('elasticsearch_port', '')
     kubeadmin_password = environment_variables_dict.get('kubeadmin_password', '')
-    benchmark_operator_workload = BenchmarkOperatorWorkloads(kubeadmin_password=kubeadmin_password, es_host=es_host, es_port=es_port, workload=workload)
-    benchmark_operator_workload.run_workload()
+    benchmark_operator_workload = BenchmarkOperatorWorkloads(kubeadmin_password=kubeadmin_password, es_host=es_host, es_port=es_port)
+    # benchmark-operator node selector
+    if environment_variables_dict.get('pin_node_benchmark_operator'):
+        benchmark_operator_workload.update_node_selector(base_path=environment_variables_dict.get('runner_path', ''),
+                                                         yaml_path='benchmark-operator/config/manager/manager.yaml',
+                                                         pin_node='pin_node_benchmark_operator')
+    # only for functional environment - put resources limit 0 in manager.yaml
+    if environment_variables_dict.get('functional_resource_limit'):
+        benchmark_operator_workload.change_resource_limit_cpu_benchmark_operator_temp_patch(base_path=environment_variables_dict.get('runner_path', ''),
+                                                             yaml_path='/benchmark-operator/config/manager/manager.yaml')
+    benchmark_operator_workload.run_workload(workload=workload)
 
 
 main()
